@@ -19,19 +19,15 @@
  */
 
 #include "config.h"
-
-#include <glib/gi18n-lib.h>
-
-#include <gtk/gtk.h>
-
-#include <telepathy-glib/telepathy-glib.h>
-
 #include "empathy-call-utils.h"
 
-#include <libempathy/empathy-request-util.h>
+#include <glib/gi18n-lib.h>
+#include <gtk/gtk.h>
+
+#include "empathy-request-util.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 static const gchar *
 get_error_display_message (GError *error)
