@@ -21,19 +21,18 @@
  *
  * Authors: Danielle Madeley <danielle.madeley@collabora.co.uk>
  */
+
 #include "config.h"
+#include "empathy-contact-blocking-dialog.h"
 
 #include <glib/gi18n-lib.h>
 
-#include <libempathy/empathy-utils.h>
-
-#include <libempathy-gtk/empathy-account-chooser.h>
-#include <libempathy-gtk/empathy-ui-utils.h>
-
-#include "empathy-contact-blocking-dialog.h"
+#include "empathy-account-chooser.h"
+#include "empathy-ui-utils.h"
+#include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 #define GET_PRIVATE(o) (EMPATHY_CONTACT_BLOCKING_DIALOG (o)->priv)
 #define DECLARE_CALLBACK(func) \
