@@ -33,14 +33,15 @@
 #define __EMPATHY_UI_UTILS_H__
 
 #include <gtk/gtk.h>
-
 #include <folks/folks.h>
 
-#include <libempathy/empathy-contact.h>
-#include <libempathy/empathy-ft-handler.h>
+#include "empathy-contact.h"
+#include "empathy-ft-handler.h"
 
 G_BEGIN_DECLS
 
+#define ACCOUNT_WIDGETS_RESOURCES_PREFIX "/org/gnome/AccountWidgets"
+
 #define EMPATHY_RECT_IS_ON_SCREEN(x,y,w,h) ((x) + (w) > 0 && \
               (y) + (h) > 0 && \
               (x) < gdk_screen_width () && \
@@ -57,6 +58,9 @@ void empathy_gtk_init (void);
 GtkBuilder * empathy_builder_get_file (const gchar *filename,
     const gchar *first_object,
     ...);
+GtkBuilder * empathy_builder_get_resource (const gchar *resourcename,
+    const gchar *first_object,
+    ...);
 void empathy_builder_connect (GtkBuilder *gui,
     gpointer user_data,
     const gchar *first_object,
